// Copyright (C) 2022-2023 David Sugar <tychosoft@gmail.com>.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.

package main

import (
	"sort"

	"github.com/gofiber/fiber/v2"

	"storehouse/lib"
)

func viewIndex(ctx *fiber.Ctx) error {
	dists, err := lib.ScanDists(config.Prefix+"/tarballs", config.Suffix)
	if err != nil {
		return err
	}

	// reverse date sort, newest entry first
	sort.Slice(dists, func(l, r int) bool {
		return dists[l].Created > dists[r].Created
	})

	// render master site index page
	lock.RLock()
	defer lock.RUnlock()
	err = ctx.Render("index", fiber.Map{
		"files": dists,
		"page":  page,
	})
	if err != nil {
		lib.Error(err)
	}
	return err
}
