// Copyright (C) 2022-2023 David Sugar <tychosoft@gmail.com>.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.

package lib

import (
	"fmt"
	"os"
	"path/filepath"
	"strings"
)

// Distribution directory index
type Dist struct {
	Name    string
	Version string
	Created string
	Size    int64
	Text    string
}

func ScanDists(path string, suffix string) ([]Dist, error) {
	files, err := filepath.Glob(path + "/*." + suffix)
	if err != nil {
		return nil, err
	}

	store, err := describe(path + "/../store/describe")
	if err != nil {
		return nil, err
	}

	slen := len(suffix) + 1
	dists := make([]Dist, len(files))
	count := 0
	for _, file := range files {
		info, err := os.Stat(file)
		if err != nil {
			continue
		}

		name := filepath.Base(file)
		name = name[:len(name)-slen]
		pos := strings.LastIndex(name, "-")
		if pos < 1 {
			continue
		}

		y, m, d := info.ModTime().Date()
		dists[count].Name = name[:pos]
		dists[count].Version = name[pos+1:]
		dists[count].Size = info.Size()
		dists[count].Created = fmt.Sprintf("%d-%02d-%02d", y, int(m), d)
		dists[count].Text = store[name[:pos]]
		count += 1
	}
	return dists[:count], nil
}
