// Copyright (C) 2021-2023 David Sugar <tychosoft@gmail.com>.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.

package lib

import (
	"bufio"
	"os"
	"strings"
)

func describe(path string) (map[string]string, error) {
	store := make(map[string]string)
	file, err := os.Open(path)
	if err != nil {
		return nil, err
	}

	defer file.Close()
	input := bufio.NewScanner(file)
	for input.Scan() {
		line := strings.TrimSpace(input.Text())
		if len(line) < 1 || line[0] == '#' {
			continue
		}

		pos := strings.Index(line, ":")
		if pos < 2 {
			continue
		}

		store[line[:pos]] = line[pos+1:]
	}
	return store, nil
}
